@@ -47,3 +47,6 @@ class CardsSendError(AMcardsException):
 
 class CampaignSendError(AMcardsException):
     """Something went wrong when attempting to send a drip campaign"""
+
+class OAuthTokenRefreshError(AMcardsException):
+    """Something went wrong when attempting to refresh AMcards access_token"""
